@@ -2,10 +2,10 @@ import click
 from arbol.arbol import aprint, asection
 
 from dexp.cli.defaults import (
-    _default_clevel,
-    _default_codec,
-    _default_store,
-    _default_workers_backend,
+    DEFAULT_CLEVEL,
+    DEFAULT_CODEC,
+    DEFAULT_STORE,
+    DEFAULT_WORKERS_BACKEND,
 )
 from dexp.cli.parsing import (
     _get_output_path,
@@ -27,15 +27,15 @@ from dexp.datasets.operations.deconv import dataset_deconv
     default=None,
     help="dataset slice (TZYX), e.g. [0:5] (first five stacks) [:,0:100] (cropping in z) ",
 )
-@click.option("--store", "-st", default=_default_store, help="Zarr store: ‘dir’, ‘ndir’, or ‘zip’", show_default=True)
+@click.option("--store", "-st", default=DEFAULT_STORE, help="Zarr store: ‘dir’, ‘ndir’, or ‘zip’", show_default=True)
 @click.option(
     "--codec",
     "-z",
-    default=_default_codec,
+    default=DEFAULT_CODEC,
     help="compression codec: ‘zstd’, ‘blosclz’, ‘lz4’, ‘lz4hc’, ‘zlib’ or ‘snappy’ ",
     show_default=True,
 )
-@click.option("--clevel", "-l", type=int, default=_default_clevel, help="Compression level", show_default=True)
+@click.option("--clevel", "-l", type=int, default=DEFAULT_CLEVEL, help="Compression level", show_default=True)
 @click.option("--overwrite", "-w", is_flag=True, help="to force overwrite of target", show_default=True)
 @click.option("--tilesize", "-ts", type=int, default=512, help="Tile size for tiled computation", show_default=True)
 @click.option(
@@ -130,7 +130,7 @@ from dexp.datasets.operations.deconv import dataset_deconv
     "--workersbackend",
     "-wkb",
     type=str,
-    default=_default_workers_backend,
+    default=DEFAULT_WORKERS_BACKEND,
     help="What backend to spawn workers with, can be ‘loky’ (multi-process) or ‘threading’ (multi-thread) ",
     show_default=True,
 )  #
