@@ -1,7 +1,7 @@
 import click
 from arbol.arbol import aprint, asection
 
-from dexp.cli.defaults import _default_workers_backend
+from dexp.cli.defaults import DEFAULT_WORKERS_BACKEND
 from dexp.cli.parsing import (
     _get_output_path,
     _parse_channels,
@@ -166,7 +166,7 @@ from dexp.datasets.operations.projrender import dataset_projection_rendering
     "--workersbackend",
     "-wkb",
     type=str,
-    default=_default_workers_backend,
+    default=DEFAULT_WORKERS_BACKEND,
     help="What backend to spawn workers with, can be ‘loky’ (multi-process) or ‘threading’ (multi-thread) ",
     show_default=True,
 )  #
