@@ -6,10 +6,13 @@ from dexp.cli.dexp_commands.check import check
 from dexp.cli.dexp_commands.copy import copy
 from dexp.cli.dexp_commands.crop import crop
 from dexp.cli.dexp_commands.deconv import deconv
+from dexp.cli.dexp_commands.denoise import denoise
 from dexp.cli.dexp_commands.deskew import deskew
 from dexp.cli.dexp_commands.extract_psf import extract_psf
 from dexp.cli.dexp_commands.fastcopy import fastcopy
+from dexp.cli.dexp_commands.fromraw import fromraw
 from dexp.cli.dexp_commands.fuse import fuse
+from dexp.cli.dexp_commands.histogram import histogram
 from dexp.cli.dexp_commands.info import info
 from dexp.cli.dexp_commands.isonet import isonet
 from dexp.cli.dexp_commands.projrender import projrender
@@ -65,13 +68,16 @@ cli.add_command(tiff)
 cli.add_command(view)
 cli.add_command(serve)
 cli.add_command(extract_psf)
+cli.add_command(fromraw)
 
 cli.add_command(deskew)
 cli.add_command(fuse)
 cli.add_command(register)
 cli.add_command(stabilize)
 cli.add_command(deconv)
+cli.add_command(denoise)
 cli.add_command(isonet)
+cli.add_command(histogram)
 
 cli.add_command(speedtest)
 
