@@ -1,25 +1,26 @@
+from typing import Optional, Tuple
+
 from arbol import aprint
 from numpy import s_
-from typing import Tuple, Optional
 
 
-def _get_output_path(input_path, output_path, postfix=''):
+def _get_output_path(input_path, output_path, postfix=""):
     if output_path is None or not output_path.strip():
         return _strip_path(input_path) + postfix
-    elif output_path.startswith('_'):
-        return _strip_path(input_path)+postfix+output_path
+    elif output_path.startswith("_"):
+        return _strip_path(input_path) + postfix + output_path
     else:
         return output_path
 
 
 def _strip_path(path):
-    if path.endswith('/') or path.endswith('\\'):
+    if path.endswith("/") or path.endswith("\\"):
         path = path[:-1]
-    if path.endswith('.zip'):
+    if path.endswith(".zip"):
         path = path[:-4]
-    if path.endswith('.nested.zarr'):
+    if path.endswith(".nested.zarr"):
         path = path[:-12]
-    if path.endswith('.zarr'):
+    if path.endswith(".zarr"):
         path = path[:-5]
     return path
 
@@ -28,7 +29,7 @@ def _parse_slicing(slicing: str):
     aprint(f"Requested slicing    : '{slicing if slicing else '--All--'}' ")
     if slicing is not None:
         aprint(f"Slicing: {slicing}")
-        dummy = s_[1, 2]
+        _ = s_[1, 2]  # ??
         slicing = eval(f"s_{slicing}")
     return slicing
 
@@ -40,7 +41,7 @@ def _parse_channels(input_dataset, channels):
     if channels is None:
         channels = input_dataset.channels()
     else:
-        channels = tuple(channel.strip() for channel in channels.split(','))
+        channels = tuple(channel.strip() for channel in channels.split(","))
         channels = [channel for channel in channels if channel in available_channels]
 
     aprint(f"Selected channel(s)  : '{channels}'")
@@ -49,11 +50,12 @@ def _parse_channels(input_dataset, channels):
 
 def _parse_devices(devices):
     aprint(f"Requested devices    :  '{'--All--' if 'all' in devices else devices}' ")
-    if 'all' in devices:
-        from dexp.processing.backends.cupy_backend import CupyBackend
+    if "all" in devices:
+        from dexp.utils.backends import CupyBackend
+
         devices = tuple(range(len(CupyBackend.available_devices())))
     else:
-        devices = tuple(int(device.strip()) for device in devices.split(','))
+        devices = tuple(int(device.strip()) for device in devices.split(","))
 
     return devices
 
