@@ -4,27 +4,30 @@ from arbol import aprint, asection
 from zarr.errors import ArrayNotFoundError
 
 
-def dataset_view_remote(input_path: str,
-                        name: str,
-                        aspect: float,
-                        channels: Sequence[str],
-                        contrast_limits: Tuple[float, float],
-                        colormap: str,
-                        slicing,
-                        windowsize: int):
+def dataset_view_remote(
+    input_path: str,
+    name: str,
+    aspect: float,
+    channels: Sequence[str],
+    contrast_limits: Tuple[float, float],
+    colormap: str,
+    slicing,
+    windowsize: int,
+):
     # Annoying napari induced warnings:
     import warnings
+
     warnings.filterwarnings("ignore")
 
     if channels is None:
         aprint("Channel(s) must be specified!")
         return
 
-    if ':' not in input_path.replace("http://", ""):
-        input_path = f'{input_path}:8000'
+    if ":" not in input_path.replace("http://", ""):
+        input_path = f"{input_path}:8000"
 
     with asection(f"Viewing remote dataset at: {input_path}, channel(s): {channels}"):
-        channels = tuple(channel.strip() for channel in channels.split(','))
+        channels = tuple(channel.strip() for channel in channels.split(","))
         channels = list(set(channels))
 
         from napari import Viewer, gui_qt
@@ -35,7 +38,8 @@ def dataset_view_remote(input_path: str,
 
             for channel in channels:
                 import dask.array as da
-                if '/' in channel:
+
+                if "/" in channel:
                     array = da.from_zarr(f"{input_path}/{channel}")
                 else:
                     array = da.from_zarr(f"{input_path}/{channel}/{channel}")
@@ -43,14 +47,16 @@ def dataset_view_remote(input_path: str,
                 if slicing is not None:
                     array = array[slicing]
 
-                layer = viewer.add_image(array,
-                                         name=channel,
-                                         visible=True,
-                                         contrast_limits=contrast_limits,
-                                         blending='additive',
-                                         colormap=colormap,
-                                         attenuation=0.04,
-                                         rendering='attenuated_mip')
+                layer = viewer.add_image(
+                    array,
+                    name=channel,
+                    visible=True,
+                    contrast_limits=contrast_limits,
+                    blending="additive",
+                    colormap=colormap,
+                    attenuation=0.04,
+                    rendering="attenuated_mip",
+                )
 
                 if aspect is not None:
                     if array.ndim == 3:
@@ -61,17 +67,19 @@ def dataset_view_remote(input_path: str,
 
                 try:
                     for axis in range(array.ndim):
-                        if '/' in channel:
+                        if "/" in channel:
                             proj_array = da.from_zarr(f"{input_path}/{channel}_max{axis}")
                         else:
                             proj_array = da.from_zarr(f"{input_path}/{channel}/{channel}_max{axis}")
 
-                        proj_layer = viewer.add_image(proj_array,
-                                                      name=f'{channel}_max{axis}',
-                                                      visible=True,
-                                                      contrast_limits=contrast_limits,
-                                                      blending='additive',
-                                                      colormap=colormap)
+                        proj_layer = viewer.add_image(
+                            proj_array,
+                            name=f"{channel}_max{axis}",
+                            visible=True,
+                            contrast_limits=contrast_limits,
+                            blending="additive",
+                            colormap=colormap,
+                        )
 
                         if aspect is not None:
                             if axis == 0:
