@@ -1,13 +1,10 @@
-from dexp.processing.backends.backend import Backend
-from dexp.processing.backends.numpy_backend import NumpyBackend
+from functools import partial
+
 from dexp.utils import xpArray
+from dexp.utils.backends import Backend, NumpyBackend
 
 
-def fuse_dct_nd(image_a: xpArray,
-                image_b: xpArray,
-                cutoff: float = 0,
-                clip: bool = True,
-                internal_dtype=None):
+def fuse_dct_nd(image_a: xpArray, image_b: xpArray, cutoff: float = 0, clip: bool = True, internal_dtype=None):
     """
     Fuses two images in DCT domain by picking coefficients with maximal magnitude.
 
@@ -53,11 +50,11 @@ def fuse_dct_nd(image_a: xpArray,
     min_value = min(min_a, min_b)
     max_value = min(max_a, max_b)
 
-    tranform = lambda x: sp.fft.dctn(x, norm='ortho')
-    itranform = lambda x: sp.fft.idctn(x, norm='ortho')
+    transform = partial(sp.fft.dctn, norm="ortho")
+    itransform = partial(sp.fft.idctn, norm="ortho")
 
-    image_a_dct = tranform(image_a)
-    image_b_dct = tranform(image_b)
+    image_a_dct = transform(image_a)
+    image_b_dct = transform(image_b)
 
     image_a_dct_abs = xp.absolute(image_a_dct)
     image_b_dct_abs = xp.absolute(image_b_dct)
@@ -69,10 +66,12 @@ def fuse_dct_nd(image_a: xpArray,
         c = cutoff
         cutoffs = tuple(int(s * c) for s in image_a.shape)
         cutoffs_slice = tuple(slice(0, c) for c in cutoffs)
-        image_fused_dct[cutoffs_slice] = ~image_a_is_max[cutoffs_slice] * image_a_dct[cutoffs_slice] \
-                                         + image_a_is_max[cutoffs_slice] * image_b_dct[cutoffs_slice]
+        image_fused_dct[cutoffs_slice] = (
+            ~image_a_is_max[cutoffs_slice] * image_a_dct[cutoffs_slice]
+            + image_a_is_max[cutoffs_slice] * image_b_dct[cutoffs_slice]
+        )
 
-    image_fused = itranform(image_fused_dct)
+    image_fused = itransform(image_fused_dct)
 
     if clip:
         image_fused = xp.clip(image_fused, min_value, max_value, out=image_fused)
