@@ -1,25 +1,29 @@
-from typing import Tuple, Union, Optional
+from typing import Callable, Optional, Sequence, Tuple, Union
 
 import numpy
 
-from dexp.processing.backends.backend import Backend
 from dexp.processing.utils.nd_slice import nd_split_slices, remove_margin_slice
-from dexp.processing.utils.normalise import normalise_functions
+from dexp.processing.utils.normalise import Normalise
+from dexp.utils import xpArray
+from dexp.utils.backends import Backend
 
 
-def scatter_gather_i2i(function,
-                       image,
-                       tiles: Union[int, Tuple[int, ...]],
-                       margins: Optional[Union[int, Tuple[int, ...]]] = None,
-                       normalise: bool = False,
-                       clip: bool = False,
-                       to_numpy: bool = True,
-                       internal_dtype=None):
+def scatter_gather_i2i(
+    function: Callable,
+    image: xpArray,
+    tiles: Union[int, Tuple[int, ...]],
+    margins: Optional[Union[int, Tuple[int, ...]]] = None,
+    normalise: bool = False,
+    clip: bool = False,
+    to_numpy: bool = True,
+    internal_dtype: Optional[numpy.dtype] = None,
+) -> xpArray:
     """
     Image-2-image scatter-gather.
-    'Scatters' computation of a given unary function by splitting the input array into tiles, computing using a given backend,
-    and reassembling the tiles into a single array of same shape as the inpout that is either backed by the same backend than
-    that of the input image, or that is backed by numpy -- usefull when the compute backend cannot hold the whole input and output
+    'Scatters' computation of a given unary function by splitting the input array into tiles,
+    computing using a given backend, and reassembling the tiles into a single array of same
+    shape as the inpout that is either backed by the same backend than that of the input image,
+    or that is backed by numpy -- usefull when the compute backend cannot hold the whole input and output
     images in memory.
 
     Parameters
@@ -27,10 +31,12 @@ def scatter_gather_i2i(function,
     function : unary function
     image : input image (can be any backend, numpy )
     tiles : tile sizes to cut input image into, can be a single integer or a tuple of integers.
-    margins : margins to add to each tile, can be a single integer or a tuple of integers. if None, no margins are added.
+    margins : margins to add to each tile, can be a single integer or a tuple of integers.
+        if None, no margins are added.
     normalise : normalises  the input image.
     clip : clip after normalisation/denormalisation
-    to_numpy : should the result be a numpy array? Very usefull when the compute backend cannot hold the whole input and output images in memory.
+    to_numpy : should the result be a numpy array? Very usefull when the compute backend
+        cannot hold the whole input and output images in memory.
     internal_dtype : internal dtype for computation
 
     Returns
@@ -55,12 +61,12 @@ def scatter_gather_i2i(function,
         margins = (margins,) * image.ndim
 
     if to_numpy:
-        result = numpy.empty(shape=image.shape, dtype=image.dtype)
+        result = numpy.empty(shape=image.shape, dtype=internal_dtype)
     else:
-        result = Backend.get_xp_module(image).empty_like(image)
+        result = Backend.get_xp_module(image).empty_like(image, dtype=internal_dtype)
 
     # Normalise:
-    norm_fun, denorm_fun = normalise_functions(image, do_normalise=normalise, clip=clip)
+    norm = Normalise(Backend.to_backend(image), do_normalise=normalise, clip=clip, quantile=0.005)
 
     # image shape:
     shape = image.shape
@@ -77,34 +83,46 @@ def scatter_gather_i2i(function,
 
     if number_of_tiles == 1:
         # If there is only one tile, let's not be complicated about it:
-        result = denorm_fun(function(norm_fun(image)))
+        result = norm.backward(function(norm.forward(image)))
         if to_numpy:
-            result = Backend.to_numpy(result, dtype=image.dtype)
+            result = Backend.to_numpy(result, dtype=internal_dtype)
         else:
-            result = Backend.to_backend(result, dtype=image.dtype)
+            result = Backend.to_backend(result, dtype=internal_dtype)
     else:
-        _scatter_gather_loop(denorm_fun, function, image, internal_dtype, norm_fun, result, shape, slices, to_numpy)
+        _scatter_gather_loop(
+            norm.backward, function, image, internal_dtype, norm.forward, result, shape, slices, to_numpy
+        )
 
     return result
 
 
-def _scatter_gather_loop(denorm_fun, function, image, internal_dtype, norm_fun, result, shape, slices, to_numpy):
+def _scatter_gather_loop(
+    denorm_fun: Callable,
+    function: Callable,
+    image: xpArray,
+    internal_dtype: numpy.dtype,
+    norm_fun: Callable,
+    result: Callable,
+    shape: Tuple[int, ...],
+    slices: Sequence[Tuple[slice, ...]],
+    to_numpy: bool,
+) -> None:
+
     for tile_slice, tile_slice_no_margins in slices:
         image_tile = image[tile_slice]
         image_tile = Backend.to_backend(image_tile, dtype=internal_dtype)
         image_tile = denorm_fun(function(norm_fun(image_tile)))
         if to_numpy:
-            image_tile = Backend.to_numpy(image_tile, dtype=image.dtype)
+            image_tile = Backend.to_numpy(image_tile, dtype=internal_dtype)
         else:
-            image_tile = Backend.to_backend(image_tile, dtype=image.dtype)
+            image_tile = Backend.to_backend(image_tile, dtype=internal_dtype)
 
-        remove_margin_slice_tuple = remove_margin_slice(
-            shape, tile_slice, tile_slice_no_margins
-        )
+        remove_margin_slice_tuple = remove_margin_slice(shape, tile_slice, tile_slice_no_margins)
         image_tile = image_tile[remove_margin_slice_tuple]
 
         result[tile_slice_no_margins] = image_tile
 
+
 # Dask turned out not too work great here, HUGE overhead compared to the light approach above.
 # def scatter_gather_dask(backend: Backend,
 #                         function,
